fsck.c: Improve log messages.
[paraslash.git] / write.h
diff --git a/write.h b/write.h
index 2eb4e3db8315ba1baedabbbfcefff369a6f3f058..71c666d663bdb2f94b8af236bb7385b18cc4ac24 100644 (file)
--- a/write.h
+++ b/write.h
@@ -101,10 +101,10 @@ struct writer_node_group {
        struct writer_node *writer_nodes;
        /** the maximum of the chunk_bytes values of the writer nodes in this group */
        size_t max_chunk_bytes;
        struct writer_node *writer_nodes;
        /** the maximum of the chunk_bytes values of the writer nodes in this group */
        size_t max_chunk_bytes;
-       /** non-zero if end of file was encountered by the feeding task */
-       int *input_eof;
-       /** non-zero if end of file was encountered */
-       int eof;
+       /** Non-zero if an error or end of file was encountered by the feeding task. */
+       int *input_error;
+       /** Non-zero if an error occurred or end of file was encountered. */
+       int error;
        /** current output buffer */
        char *buf;
        /** number of bytes loaded in the output buffer */
        /** current output buffer */
        char *buf;
        /** number of bytes loaded in the output buffer */